@@ -1197,6 +1197,14 @@ gboolean avi_delete(AviEdit *avi_edit,gint start,gint samples)
 		samples=avi_edit->length-start;
 	if (samples<=0 || avi_edit->length<=samples)
 		return FALSE;
+	/* å */
+	if (start<=avi_edit->pos && avi_edit->pos<start+samples) {
+		g_free(avi_edit->buf);
+		avi_edit->buf=NULL;
+		avi_edit->pos=-1;
+	} else if (start+samples<=avi_edit->pos) {
+		avi_edit->pos-=samples;
+	}
 
 	avi_split_file(avi_edit,start);/* AVIեʬ䤹 */
 	p=avi_edit->file;
@@ -1336,6 +1344,9 @@ gboolean avi_paste(AviEdit *avi_dst,gint pos,AviEdit *avi_src)
 								|| memcmp(avi_dst->wfx,avi_src->wfx,length)!=0)
 			return FALSE;/* եޥåȤۤʤ */
 	}
+	/* å */
+	if (pos<=avi_dst->pos)
+		avi_dst->pos+=avi_src->length;
 	if (pos<avi_dst->length) {
 		/* Žդ֤ʬ䤹 */
 		avi_split_file(avi_dst,pos);
