@@ -248,6 +248,19 @@ void clear_sel(VmaidWindow *vmaid,
 			rc1=rc;
 			gdk_rectangle_union(&rc0,&rc1,&rc);
 		}
+		if (cursor->frame==vmaid->top || cursor->frame==vmaid->top+sx
+							|| cursor->frame==top || cursor->frame==top+sx) {
+			/* üΥå */
+			rc0.x=cursor->frame==vmaid->top || cursor->frame==top
+										?vmaid->width+1:vmaid->width*(sx+1)+2;
+			rc0.y=system_fontheight*2
+								+(vmaid->avi[0]!=NULL && cursor->stream>0
+															?vmaid->height:0);
+			rc0.width=1;
+			rc0.height=vmaid->height;
+			rc1=rc;
+			gdk_rectangle_union(&rc0,&rc1,&rc);
+		}
 	} else {
 		rc.x=-1;
 	}
@@ -441,7 +454,7 @@ gboolean prompt_close(VmaidWindow *vmaid)
 					_("ե %s ƤѹƤޤ\n¸ޤ?"),
 																vmaid->file);
 		switch (message_box("Video maid",text,0,
-						_("Ϥ(_Y)"),_("(_N)"),_("󥻥"),NULL)) {
+							_("Ϥ(_Y)"),_("(_N)"),_(""),NULL)) {
 			case 0:
 				command_save(NULL,0,NULL);
 				if (!vmaid->edit)
