@@ -131,7 +131,7 @@ int main(int argc,char *argv[])
 {N_("/ץ(_O)"),                     NULL,         NULL,            0,"<Branch>"},
 {N_("/ץ(O)/(_C)..."),          NULL,         conf_dialog,     0,"<Item>"},
 {N_("/(_T)"),                         NULL,         NULL,            0,"<Branch>"},
-{N_("/(T)/󥻥(_C)"),           NULL,         command_cancel,  0,"<Item>"},
+{N_("/(T)/(_C)"),                 NULL,         command_cancel,  0,"<Item>"},
 {N_("/ɥ(_W)"),                     NULL,         NULL,            0,"<Branch>"},
 {N_("/إ(_H)"),                         NULL,         NULL,            0,"<Branch>"},
 {N_("/إ(H)/С(_A)..."),    NULL,         version_dialog,  0,"<Item>"}};
